## Spacing & Kerning

The space between glyphs is controlled by their spacing and kerning.
_Spacing_ defines the general white space surrounding a glyph, while _kerning_ makes adjustments to specific glyph pairs.